package user

import (
	"github.com/ArtisanCloud/PowerWeChat/v3/src/miniProgram"
	"github.com/cloudwego/hertz/pkg/app/server"
	"github.com/cloudwego/hertz/pkg/common/hlog"
	"gitlab.com/kedaya_mp/user/biz/handle"
	"gitlab.com/kedaya_mp/user/biz/mw"
	user_service "gitlab.com/kedaya_mp/user/biz/service"
	"gitlab.com/kedaya_mp/user/pkg/captcha"
	"gorm.io/gorm"
)

func Register(h *server.Hertz, db *gorm.DB, miniProgramApp *miniProgram.MiniProgram, captchaService captcha.Service) {
	userService := user_service.NewUserService(db, miniProgramApp, captchaService)
	if err := userService.Init(); err != nil {
		hlog.Fatalf("UserService Init Error: %v", err)
	}
	userHandler := handle.NewUserHandler(userService)
	authMiddleware := mw.NewJwt(userHandler.Authenticator)

	api := h.Group("/api/v1")
	api.POST("/login", authMiddleware.LoginHandler)

	// 需要JWT认证的接口
	auth := api.Group("/")
	auth.Use(authMiddleware.MiddlewareFunc())
	{
		auth.GET("/user", userHandler.GetUserByPhone)
	}
}
